LtpReq

Enum LtpReq 

#[non_exhaustive]
pub enum LtpReq { None = 0, Lfsr0 = 1, Lfsr1 = 2, Lfsr2 = 3, Lfsr3 = 4, }
Link Training Pattern requested by the sink via Status_Flags_1 bits[7:4].

An undefined nibble value from the sink surfaces as ProtocolError::UnknownLtpReq.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


None = 0

No LTP requested; training is complete or not yet started.



Lfsr0 = 1

Request LFSR0 training pattern on all active lanes.



Lfsr1 = 2

Request LFSR1 training pattern on all active lanes.



Lfsr2 = 3

Request LFSR2 training pattern on all active lanes.



Lfsr3 = 4

Request LFSR3 training pattern on all active lanes.